==> huaweicloudsdkelb-3.0.82-py2.py3-none-any.whl: huaweicloudsdkelb/v3/model/create_security_policy_request_body.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateSecurityPolicyRequestBody:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'security_policy': 'CreateSecurityPolicyOption'
    }

    attribute_map = {
        'security_policy': 'security_policy'
    }

    def __init__(self, security_policy=None):
        """CreateSecurityPolicyRequestBody - a model defined in huaweicloud sdk"""
        
        

        self._security_policy = None
        self.discriminator = None

        self.security_policy = security_policy

    @property
    def security_policy(self):
        """Gets the security_policy of this CreateSecurityPolicyRequestBody.


        :return: The security_policy of this CreateSecurityPolicyRequestBody.
        :rtype: CreateSecurityPolicyOption
        """
        return self._security_policy

    @security_policy.setter
    def security_policy(self, security_policy):
        """Sets the security_policy of this CreateSecurityPolicyRequestBody.


        :param security_policy: The security_policy of this CreateSecurityPolicyRequestBody.
        :type: CreateSecurityPolicyOption
        """
        self._security_policy = security_policy

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateSecurityPolicyRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkelb-3.1.2-py2.py3-none-any.whl: huaweicloudsdkelb/v3/model/create_security_policy_request_body.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateSecurityPolicyRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'security_policy': 'CreateSecurityPolicyOption'
    }

    attribute_map = {
        'security_policy': 'security_policy'
    }

    def __init__(self, security_policy=None):
        """CreateSecurityPolicyRequestBody

        The model defined in huaweicloud sdk

        :param security_policy: 
        :type security_policy: :class:`huaweicloudsdkelb.v3.CreateSecurityPolicyOption`
        """
        
        

        self._security_policy = None
        self.discriminator = None

        self.security_policy = security_policy

    @property
    def security_policy(self):
        """Gets the security_policy of this CreateSecurityPolicyRequestBody.


        :return: The security_policy of this CreateSecurityPolicyRequestBody.
        :rtype: :class:`huaweicloudsdkelb.v3.CreateSecurityPolicyOption`
        """
        return self._security_policy

    @security_policy.setter
    def security_policy(self, security_policy):
        """Sets the security_policy of this CreateSecurityPolicyRequestBody.


        :param security_policy: The security_policy of this CreateSecurityPolicyRequestBody.
        :type security_policy: :class:`huaweicloudsdkelb.v3.CreateSecurityPolicyOption`
        """
        self._security_policy = security_policy

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateSecurityPolicyRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
